Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLev Dragunov <l.dragunov@corp.mail.ru>2015-07-16 13:07:19 +0300
committerAlex Zolotarev <alex@maps.me>2015-09-23 02:56:26 +0300
commit45faef6be3270c5d7a4fce25d04b06a5308ec8cc (patch)
tree1641436afe5c30449f09a9b1109cfc39af2c6355 /indexer/features_offsets_table.hpp
parent9edc10dbc26d9900498f12747eea83e669847880 (diff)
Routing indexes new file API support.
Diffstat (limited to 'indexer/features_offsets_table.hpp')
-rw-r--r--indexer/features_offsets_table.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/indexer/features_offsets_table.hpp b/indexer/features_offsets_table.hpp
index 25017a463f..72c28fcbb5 100644
--- a/indexer/features_offsets_table.hpp
+++ b/indexer/features_offsets_table.hpp
@@ -1,8 +1,8 @@
#pragma once
-#include "coding/file_container.hpp"
#include "coding/mmap_reader.hpp"
#include "defines.hpp"
+#include "platform/local_country_file.hpp"
#include "std/cstdint.hpp"
#include "std/unique_ptr.hpp"
#include "std/vector.hpp"
@@ -65,10 +65,10 @@ namespace feature
/// \warning May take a lot of time if there is no precomputed section
///
/// \param fileName a full path of the file to load or store data
/// \param mwmFileContainer mwm container to read features data (if we need to construct them)
/// \return a pointer to an instance of FeaturesOffsetsTable or nullptr
/// when it's not possible to create FeaturesOffsetsTable.
- static unique_ptr<FeaturesOffsetsTable> CreateIfNotExistsAndLoad(string const & fileName, FilesContainerR const & mwmFileContainer);
+ static unique_ptr<FeaturesOffsetsTable> CreateIfNotExistsAndLoad(string const & fileName, platform::LocalCountryFile const & localFile);
FeaturesOffsetsTable(FeaturesOffsetsTable const &) = delete;
FeaturesOffsetsTable const & operator=(FeaturesOffsetsTable const &) = delete;
@@ -65,10 +65,10 @@ namespace feature
///
/// \param fileName a full path of the file to load or store data
- /// \param mwmFileContainer mwm container to read features data (if we need to construct them)
+ /// \param localFile Representation of the map files with features data ( uses only if we need to construct them)
/// \return a pointer to an instance of FeaturesOffsetsTable or nullptr
/// when it's not possible to create FeaturesOffsetsTable.